@@ -7,7 +7,7 @@
 <table border="1">
 <tr><th>KEY</th><th>subject</th><th>date</th></tr>
 <?cs if:IsToken1 ?><?cs each:item = Tokens ?><tr><td>Directory</td><td><a href="<?cs var:html_escape(item.token) ?>/index.html">#<?cs var:html_escape(BBS) ?><?cs var:html_escape(item.token) ?></a></td><td>-</td></tr><?cs /each ?><?cs /if ?>
-<?cs if:IsToken2 ?><?cs each:item = Archives ?><tr><td><?cs var:html_escape(item.key) ?></td><td><a href="<?cs var:html_escape(BaseURI) ?>/<?cs var:html_escape(BBS) ?>/kako/<?cs var:html_escape(item.token1) ?>/<?cs var:html_escape(item.token2) ?>/<?cs var:html_escape(item.key) ?>.html"><?cs var:item.subject ?></a></td><td><?cs var:html_escape(item.date) ?></td></tr><?cs /each ?><?cs /if ?>
+<?cs if:IsToken2 ?><?cs each:item = Archives ?><tr><td><?cs var:html_escape(item.key) ?></td><td><a href="<?cs var:html_escape(BaseURI) ?>/<?cs var:html_escape(BBS) ?>/kako/<?cs var:html_escape(item.token1) ?>/<?cs var:html_escape(item.token2) ?>/<?cs var:html_escape(item.key) ?>.html"><?cs var:item.subject ?></a></td><td><?cs var:item.date ?></td></tr><?cs /each ?><?cs /if ?>
 </table><hr>
 <a href="<?cs var:html_escape(BaseURI) ?>/<?cs var:html_escape(BBS) ?>/">fɖ߂遡</a> |
 <a href="<?cs var:html_escape(BaseURI) ?>/<?cs var:html_escape(BBS) ?>/kako/">ߋOgbvɖ߂遡</a> |
