@@ -1,5 +1,6 @@
 <html>
 <title><?cs var:html_escape(BBS_TITLE) ?></title>
+<meta http-equiv="Content-Type" content="text/html;charset=sjis">
 <body>
 <?cs if:Banner ?><?cs var:Banner ?><hr><?cs /if ?>
 <a name=u></a>
@@ -24,6 +25,7 @@
 <a href=<?cs var:html_escape(CGIURI) ?>/r.cgi/<?cs var:html_escape(BBS) ?>/w accesskey=4></a>
 <a href=<?cs var:html_escape(CGIURI) ?>/r.cgi/<?cs var:html_escape(BBS) ?>/c accesskey=5></a>
 <a href=<?cs var:html_escape(CGIURI) ?>/r.cgi/<?cs var:html_escape(BBS) ?>/. accesskey=6></a>
+<a href=<?cs var:html_escape(CGIURI) ?>/img0ch-st.cgi/<?cs var:html_escape(BBS) ?>/?m=1></a>
 <?cs if:BBS_ACCEPT_MAILPOST ?>
 <a href=<?cs var:html_escape(CGIURI) ?>/m.cgi/<?cs var:html_escape(BBS) ?>/>X</a>
 <?cs /if ?>
