@@ -39,7 +39,7 @@
 <form action=c>
 <textarea><?cs var:html_escape(Title) ?><?cs var:html_escape(CR) ?><?cs var:html_escape(BBSURI) ?></textarea><hr>
 <?cs each:item = Threads ?>
-<textarea><?cs var:html_escape(item.index) ?>:<?cs var:html_escape(item.subject) ?>  (<?cs var:html_escape(item.res) ?>)
+<textarea><?cs var:html_escape(item.index) ?>:<?cs var:item.subject ?>  (<?cs var:html_escape(item.res) ?>)
 <?cs var:html_escape(CR) ?>
 <?cs var:html_escape(CGIURI) ?>/read.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(item.key) ?>/
 </textarea><br><?cs /each ?></form>
@@ -49,7 +49,7 @@
 <?cs var:html_escape(item.index) ?>:<a href=<?cs if:QueryString ?>
 <?cs var:html_escape(RCGIURI) ?>/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(item.key) ?>/<?cs var:html_escape(QueryString) ?>
 <?cs else ?><?cs var:html_escape(item.key) ?><?cs /if ?>/i>
-<?cs var:html_escape(item.subject) ?>  (<?cs var:html_escape(item.res) ?>)</a><br>
+<?cs var:item.subject ?>  (<?cs var:html_escape(item.res) ?>)</a><br>
 <?cs /each ?>
 <?cs if:Search ?><?cs var:html_escape(Count) ?> thread hit<?cs /if ?>
 <?cs /if ?>
