@@ -6,10 +6,7 @@
 <meta http-equiv="Content-Style-Type" content="text/css">
 <meta name="Robot" content="NOINDEX,NOFOLLOW">
 <meta name="VERSION" content="<?cs var:html_escape(VERSION) ?>">
-<script src="<?cs var:html_escape(StaticURI) ?>/js/jquery-1.1.js" charset="UTF-8"></script>
-<script src="<?cs var:html_escape(StaticURI) ?>/js/jquery/cookie.js" charset="UTF-8"></script>
-<script src="<?cs var:html_escape(StaticURI) ?>/js/jquery/fastserialize.js"></script>
-<script src="<?cs var:html_escape(StaticURI) ?>/js/img0ch/app.js" charset="UTF-8"></script>
+<script src="<?cs var:html_escape(StaticURI) ?>/js/img0ch.js" charset="UTF-8"></script>
 <script type="text/javascript">
 //<!--
 var app = Img0ch.App;
@@ -71,10 +68,16 @@ function confirmSubmit() {
         alert("Avbgǂݍ܂Ă܂");
         return;
     }
-    jQuery("//input[@name='post']").attr({
-        "value": ( jQuery("input#temporarySave").get(0).checked ? 0 : 1 ) });
-    document.paintbbs.str_header = jQuery.param(jQuery("form#notePostForm").fastSerialize());
+    
+    jQuery("form.comment").unbind("submit");
+    try { event.returnValue = false; } catch(e) {}
+    
+    jQuery("input[@name='post']").attr({
+        "value": ( jQuery("#temporarySave").get(0).checked ? 0 : 1 ) });
+    document.paintbbs.str_header = jQuery("#notePostForm").serialize();
     applet.pExit();
+    
+    return false;
 }
 
 function paintBBSCallback(callbackValue) {
@@ -82,7 +85,7 @@ function paintBBSCallback(callbackValue) {
         var option = { "expires": 30, "path": "<?cs var:html_escape(BBS_COOKIE_PATH) ?>" };
         jQuery.cookie( "NAME", jQuery( "input[@name='FROM']", this ).val(), option );
         jQuery.cookie( "MAIL", jQuery( "input[@name='mail']", this ).val(), option );
-        return jQuery.param(jQuery("form#notePostForm").fastSerialize());
+        return jQuery("#notePostForm").serialize();
     }
 }
 
@@ -223,7 +226,7 @@ esɂJavaScriptLɂKv܂B
 </noscript>
 <form class="comment" id="notePostForm" method="POST"
   action="<?cs var:html_escape(CGIURI) ?>/img0ch-note.cgi"
-  onsubmit="confirmSubmit(); return false">
+  onsubmit="return confirmSubmit()">
 <input type="submit" value="e" name="submit">
 <input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>">
 <input type="hidden" name="time" value="<?cs var:html_escape(TimeStamp) ?>">
