@@ -1,6 +1,6 @@
 <html>
 <head>
-<title>img0ch - <?cs if:Subject ?>u<?cs var:html_escape(Subject) ?>v<?cs /if ?>zXbhǗ</title>
+<title>img0ch - <?cs if:Subject ?>u<?cs var:Subject ?>v<?cs /if ?>zXbhǗ</title>
 <meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS">
 <meta http-equiv="Content-Script-Type" content="text/javascript">
 <meta http-equiv="Content-Style-Type" content="text/css">
@@ -209,7 +209,7 @@ p̃XbhɃ[UƃpX[h݂A<br>
 </p>
 <form id="virtualThreadForm" action="<?cs var:html_escape(CGIURI) ?>/img0ch-vta.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(KEY) ?>/" method="POST">
 <select name="inherit_from">
-<?cs each:item = Threads ?><option value="<?cs var:html_escape(item.key) ?>"><?cs var:html_escape(item.subject) ?> (<?cs var:html_escape(item.res) ?>)</option>
+<?cs each:item = Threads ?><option value="<?cs var:html_escape(item.key) ?>"><?cs var:item.subject ?> (<?cs var:html_escape(item.res) ?>)</option>
 <?cs /each ?></select>
 <input type="submit" name="submit" value="ݒ̌p">
 <input type="hidden" name="mode" value="inherit">
@@ -265,7 +265,7 @@ p̃XbhɃ[UƃpX[h݂A<br>
 <hr>
 
 <dl>
-<font color="<?cs var:html_escape(BBS_SUBJECT_COLOR) ?>" size="+1"> <?cs var:html_escape(Subject) ?></font><br><br>
+<font color="<?cs var:html_escape(BBS_SUBJECT_COLOR) ?>" size="+1"> <?cs var:Subject ?></font><br><br>
 
 <?cs each:item = Thread ?><dt><input type="checkbox" name="resno" value="<?cs var:html_escape(item.resno) ?>"> <?cs var:html_escape(item.resno) ?> OF<b><?cs if:item.mail ?><a href="mailto:<?cs var:html_escape(item.mail) ?>"><?cs var:item.name ?></a><?cs else ?><font color="<?cs var:html_escape(BBS_NAME_COLOR) ?>"><?cs var:item.name ?></font><?cs /if ?></b>F<?cs var:item.date ?> <a href="#virtualThreadForm"></a></dt><dd><?cs var:item.text ?><br><br></dd>
 <?cs /each ?>
