@@ -16,7 +16,7 @@
   &gt;
   <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">スレッド整理</a>
   &gt;
-  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_pooled_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">プールスレッド整理</a>
+  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_pooled_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;sort_by=<?cs var:html_escape(SortBy) ?>&amp;descend=<?cs var:html_escape(Descend) ?>" onclick="Zeromin2.redirect(this);return false">プールスレッド整理</a>
 </div>
 
 <h1>プールスレッド整理</h1>
@@ -31,8 +31,6 @@
 <?cs if:Code2 ?><div class="noticeFailed" id="notify"><p>操作対象のプールスレッドが選択されていません</p></div><?cs /if ?>
 <?cs /if ?>
 
-<script src="<?cs var:html_escape(StaticURI) ?>/js/domTT/domLib.js"></script>
-<script src="<?cs var:html_escape(StaticURI) ?>/js/domTT/domTT.js"></script>
 <script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/zeromin2/lookup.js" charset="UTF-8"></script>
 <script type="text/javascript" charset="UTF-8">
 //<![CDATA[
@@ -41,7 +39,7 @@ Zeromin2.addStyleSheet("<?cs var:html_escape(StaticURI) ?>/css/domTT.css");
 });
 function lookup( ip, element, event ) {
     Zeromin2.lookup(
-        jQuery("form#pooledThreadsContainerForm").get(0), ip, element, event );
+        jQuery("#pooledThreadsContainerForm").get(0), ip, element, event );
 }
 //]]>
 </script>
@@ -51,6 +49,7 @@ function lookup( ip, element, event ) {
 </p>
 <p>
 <ul>
+<li>それぞれの項目をクリックするとその項目にあわせて整列されます。</li>
 <li>IPアドレス欄はIPアドレスをクリックし、赤くなったらもう一度クリックすることで詳細が表示されます。</li>
 <li><code style="font-weight:bold">[HL]</code>をクリックすることで投稿者の投稿記録が全て表示されます。</li>
 </ul>
@@ -71,17 +70,24 @@ function lookup( ip, element, event ) {
 <input type="text" name="item" size="5" value="<?cs var:html_escape(Item) ?>" /><br />
 (&nbsp;<?cs var:html_escape(Total) ?>件&nbsp;-&nbsp;現在<?cs var:html_escape(Current) ?>ページ目&nbsp;)<br />
 <span class="page">
-<?cs if:Prev ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_pooled_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Prev) ?>" onclick="Zeromin2.redirect(this);return false">&lt;&lt;&nbsp;前</a><?cs /if ?>
+<?cs if:Prev ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_pooled_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Prev) ?>&amp;sort_by=<?cs var:html_escape(SortBy) ?>&amp;descend=<?cs var:html_escape(Descend) ?>" onclick="Zeromin2.redirect(this);return false">&lt;&lt;&nbsp;前</a><?cs /if ?>
 <?cs each:item = Pages ?>
-<a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_pooled_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(item.num) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(item.num) ?></a>
+<a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_pooled_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(item.num) ?>&amp;sort_by=<?cs var:html_escape(SortBy) ?>&amp;descend=<?cs var:html_escape(Descend) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(item.num) ?></a>
 <?cs /each ?>
-<?cs if:Next ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_pooled_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Next) ?>" onclick="Zeromin2.redirect(this);return false">次&nbsp;&gt;&gt;</a><?cs /if ?>
+<?cs if:Next ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_pooled_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Next) ?>&amp;sort_by=<?cs var:html_escape(SortBy) ?>&amp;descend=<?cs var:html_escape(Descend) ?>" onclick="Zeromin2.redirect(this);return false">次&nbsp;&gt;&gt;</a><?cs /if ?>
 </span>
 </p>
 
 <table class="simple">
   <thead>
-    <tr><td><input type="checkbox" name="" value="" onclick="Zeromin2.selectAllCheckbox( this, 'thread' )" /></td><td>スレッド名</td><td>レス数</td><td>時刻</td><td>IPアドレス</td><td>&nbsp;</td></tr>
+    <tr>
+      <td><input type="checkbox" name="" value="" onclick="Zeromin2.selectAllCheckbox( this, 'thread' )" /></td>
+      <td><a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_pooled_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;sort_by=subject&amp;descend=<?cs if:Descend ?>0<?cs else ?>1<?cs /if ?>" onclick="Zeromin2.redirect(this);return false">スレッド名</a></td>
+      <td><a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_pooled_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;sort_by=count&amp;descend=<?cs if:Descend ?>0<?cs else ?>1<?cs /if ?>" onclick="Zeromin2.redirect(this);return false">レス数</a></td>
+      <td><a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_pooled_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;sort_by=date&amp;descend=<?cs if:Descend ?>0<?cs else ?>1<?cs /if ?>" onclick="Zeromin2.redirect(this);return false">時刻</a></td>
+      <td><a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_pooled_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;sort_by=ip&amp;descend=<?cs if:Descend ?>0<?cs else ?>1<?cs /if ?>" onclick="Zeromin2.redirect(this);return false">IPアドレス</a></td>
+      <td>&nbsp;</td>
+    </tr>
   </thead>
   <tbody>
   <?cs each:item = Entries ?>
@@ -97,6 +103,8 @@ function lookup( ip, element, event ) {
 <input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>" />
 <input type="hidden" name="OK" value="load_pooled_threads" />
 <input type="hidden" name="NG" value="load_pooled_threads" />
+<input type="hidden" name="sort_by" value="<?cs var:html_escape(SortBy) ?>" />
+<input type="hidden" name="descend" value="<?cs var:html_escape(Descend) ?>" />
 <br id="endmain" />
 </div>
 
