@@ -65,7 +65,7 @@ IPアドレス(及び固有識別番号)の検索をします。
   </thead>
   <tbody>
   <?cs each:item = Entries ?>
-    <tr><td><a href="<?cs var:html_escape(ZerominScript) ?>?class=thread&amp;method=load&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;key=<?cs var:html_escape(item.key) ?>&amp;option=<?cs var:html_escape(item.resno) ?>n&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(item.subject) ?></a></td><td><?cs var:html_escape(item.resno) ?></td><td><code><?cs var:html_escape(item.date) ?></code></td><td><?cs var:html_escape(item.agent) ?></td></tr>
+    <tr><td><a href="<?cs var:html_escape(ZerominScript) ?>?class=thread&amp;method=load&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;key=<?cs var:html_escape(item.key) ?>&amp;option=<?cs var:html_escape(item.resno) ?>n&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:item.subject ?></a></td><td><?cs var:html_escape(item.resno) ?></td><td><code><?cs var:html_escape(item.date) ?></code></td><td><?cs var:html_escape(item.agent) ?></td></tr>
   <?cs /each ?>
   </tbody>
 </table>
