@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007-2009 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2010 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: BBS.pm 1874 2009-12-01 17:54:35Z hikarin $
+# $Id: BBS.pm 2002 2010-02-21 13:28:07Z hikarin $
 #
 
 package Img0ch::App::BBS;
@@ -519,7 +519,10 @@ sub get_date {
         $iApp->{__bbs}->get_name() );
 
     if ( $iSetting->is_checked('BBS_SLIP') ) {
-        $mode = $iApp->{_request}->get_device_mark( $iApp->{__agent}, $host );
+        $mode
+            = $iApp->{_request}->get_device_mark( $iApp->{__agent}, $host,
+            $iApp->{_request}->get_header('user-agent'),
+            );
     }
     if ( $iSetting->is_checked('BBS_NO_ID') ) {
         $id = length $mode ? " ${mode}" : '';
@@ -675,7 +678,7 @@ sub update_subback {
         $i++;
     }
 
-    my $iMeta = $iBBS->get_metadata_instance();
+    my $iMeta = $iApp->{__meta} ||= $iBBS->get_metadata_instance();
     my $param = {
         ( map { %{$_} } @{ $iApp->{__template_tag_subback} } ),
         'Banner'            => $iMeta->main_banner(),
@@ -693,8 +696,6 @@ sub update_subback {
         }
     );
     $iTemplate->param($param);
-    $iApp->{__meta} = $iMeta;
-
     $iTemplate->save( $iBBS->path('subback.html') );
     1;
 }
@@ -826,23 +827,13 @@ sub update_index {
     1;
 }
 
-sub get_poster_id {
-    my ( $iClass, $now, @argument ) = @_;
-    my @time = localtime($now);
-    return substr Digest::MD5::md5_base64(
-        @argument, $time[5], $time[4], $time[3] + 31
-        ),
-        0, 8;
-}
+sub get_poster_id { shift->get_day_id(@_); }
 
 sub get_day_id {
     my ( $iApp, $now, @argument ) = @_;
-    my @time = localtime($now);
-    push @argument, ( $time[5], $time[4], $time[3] + 31 );
-    if ( $iApp->{_host} =~ /(?:p2\.2ch\.net|razil\.jp)\z/xms ) {
-        my $ua = $iApp->{_request}->get_header('user-agent');
-        push @argument;
-    }
+    my $iBBS = $iApp->{__bbs};
+    my $iMeta = $iApp->{__meta} ||= $iBBS->get_metadata_instance();
+    push @argument, $iMeta->random_data_ymd($now);
     return substr Digest::MD5::md5_base64(@argument), 0, 8;
 }
 
@@ -1248,6 +1239,7 @@ sub _upload {
 
     $iUpload->set_remove_password($remove_key);
     $iUpload->save();
+    $iUpload->update_csv($resno);
 
     my $comment = $iApp->{__param_MESSAGE} || '';
     my $path = $iUpload->path( $resno, $ext );
@@ -1326,7 +1318,8 @@ sub redirect_success {
             }
         );
         my $is_mobile = $iApp->{_serial} ? 1 : 0;
-        my $main_banner = $iBBS->get_metadata_instance()->main_banner();
+        my $iMeta = $iApp->{__meta} ||= $iBBS->get_metadata_instance();
+        my $main_banner = $iMeta->main_banner();
         $iTemplate->param(
             {   ( map { %{$_} } @{ $iApp->{__template_tag_redirect} } ),
                 'Banner'       => $main_banner,
@@ -1462,7 +1455,7 @@ sub _update_index_thread {
     my $error   = 0;
     my $iterate = $count;
     if ( !$iThread->can_write( \$error ) ) {
-        if ( $error == 1 or $error == 2 ) {
+        if ( $error == 1 ) {
             $iterate++;
         }
     }
