@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007-2008 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2010 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: BBS.pm 1645 2008-02-06 15:40:18Z hikarin $
+# $Id: BBS.pm 1901 2009-12-31 02:40:20Z hikarin $
 #
 
 package Img0ch::BBS;
@@ -62,10 +62,15 @@ sub new {
     }
 
     bless {
-        _dir    => $dir,
-        _id     => $id,
-        _path   => join( '/', $iConfig->get('BBSPath'), $dir ),
-        _url    => join( '/', $iConfig->get('Server'), $dir ),
+        _dir  => $dir,
+        _id   => $id,
+        _path => join( '/', $iConfig->get('BBSPath'), $dir ),
+        _url  => join( '/', $iConfig->get('Server'), $dir ),
+        _utf8 => (
+                   $iRepos->get("I:B.i.${id}.utf8")
+                || $iRepos->get("I.B.d.${dir}.utf8")
+                || 0
+        ),
         _kernel => $iKernel,
         _repos  => $iRepos,
         _system =>
@@ -81,6 +86,10 @@ sub get_system_repos { $_[0]->{_system} }
 
 sub get_id { $_[0]->{_id} }
 
+sub is_utf8 { $_[0]->{_utf8} ? 1 : 0 }
+
+sub get_encoding { $_[0]->{_utf8} ? 'utf8' : 'sjis' }
+
 *id = \&get_id;
 
 sub get_name { $_[0]->{_dir} }
