@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007-2008 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2010 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: NGWord.pm 1645 2008-02-06 15:40:18Z hikarin $
+# $Id: NGWord.pm 1901 2009-12-31 02:40:20Z hikarin $
 #
 
 package Img0ch::Filter::NGWord;
@@ -27,7 +27,10 @@ sub new {
 
     bless {
         _bbs => ( $iBBS->get_name() || 'test' ),
-        _rs => $iKernel->get_repos( $iKernel->get_repos_path('ngword') ),
+        _encoding => $iBBS->get_encoding(),
+        _kernel   => $iKernel,
+        _rs   => $iKernel->get_repos( $iKernel->get_repos_path('ngword') ),
+        _utf8 => $iBBS->is_utf8(),
     }, $iClass;
 }
 
@@ -57,21 +60,36 @@ sub write_ok {
         $prefix_regex
     );
 
+    my $iKernel  = $iFNGW->{_kernel};
+    my $bbs_utf8 = $iFNGW->{_utf8};
+    my $encoding = $iFNGW->{_encoding};
+
     for my $id ( keys %{$id_table} ) {
         my $prefix = "${prefix_top}.${id}";
         my $flag   = $iRepos->get_int("${prefix}.flag") || next;
         my $regex  = $iRepos->get_binary("${prefix}.regex");
         while ( my ( $key, $text ) = each %$input ) {
             $text or next;
+            if ( !$bbs_utf8 ) {
+                $text = $iKernel->get_encoded_str( $text, 'utf8', $encoding );
+            }
             if ( $text =~ /$regex/xms ) {
                 if ( $flag & 4 ) {
                     my $to = $iRepos->get_binary("${prefix}.replace");
                     $text =~ s/$regex/$to/gxms;
+                    if ( !$bbs_utf8 ) {
+                        $text = $iKernel->get_encoded_str( $text, $encoding,
+                            'utf8' );
+                    }
                     $input->{$key} = $text;
                     next;
                 }
                 elsif ( $flag & 2 ) {
                     $text =~ s/$regex//gxms;
+                    if ( !$bbs_utf8 ) {
+                        $text = $iKernel->get_encoded_str( $text, $encoding,
+                            'utf8' );
+                    }
                     $input->{$key} = $text;
                     next;
                 }
