@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Maple.pm 1977 2010-01-23 16:05:54Z hikarin $
+# $Id: Maple.pm 2013 2010-03-28 14:50:09Z hikarin $
 #
 
 package Img0ch::Maple;
@@ -22,8 +22,8 @@ package Img0ch::Maple;
 use strict;
 use Fcntl qw(:DEFAULT :flock);
 
-$Img0ch::Maple::RCS_ID  = '$Id: Maple.pm 1977 2010-01-23 16:05:54Z hikarin $';
-$Img0ch::Maple::VERSION = '3.1.6';
+$Img0ch::Maple::RCS_ID  = '$Id: Maple.pm 2013 2010-03-28 14:50:09Z hikarin $';
+$Img0ch::Maple::VERSION = '3.1.9';
 $Img0ch::Maple::revision = do {
     my @rv = $Img0ch::Maple::RCS_ID =~ /(\d+)/xms;
     $rv[0];
@@ -315,6 +315,8 @@ sub translate_symbol {
         }
         my $fh = $iMaple->get_read_file_handle($path);
         while ( my $line = <$fh> ) {
+            chomp $line;
+            $line or next;
             my ( $name, $value ) = split '=', $line;
             $name  =~ s/\A\s+//xms;
             $name  =~ s/\s+\z//xms;
