@@ -14,13 +14,15 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Interface.pm 1917 2010-01-17 10:34:52Z hikarin $
+# $Id: Interface.pm 2002 2010-02-21 13:28:07Z hikarin $
 #
 
 package Img0ch::Request::Interface;
 
 use strict;
 
+our $MAX_DEVICE_MARK_NUM = 8;
+
 sub init {
     my ( $iRequest, $iConfig, $ip, $now, $e ) = @_;
     my ( $system_path, $token_type ) = ( '', '' );
@@ -171,14 +173,20 @@ sub get_remote_host {
 sub get_device_id {
     my ( $iRequest, $agent ) = @_;
     my $ag = Img0ch::Maple::intval( $agent || $iRequest->{__agent} );
-    $ag > 6 and return '';
+    $ag > $MAX_DEVICE_MARK_NUM and return '';
     my $id = [
+
+        # others
         sub {''},
+
+        # docomo
         sub {
             my $guid = $_[0]->get_header('x-dcmguid');
             return $1 if $guid =~ /\A(\w{7})\z/xms;
             '';
         },
+
+        # softbank
         sub {
             my $agent  = $_[0]->get_header('user-agent');
             my $serial = '';
@@ -194,34 +202,62 @@ sub get_device_id {
             $serial =~ s/\s\w*\z//xms;
             $serial;
         },
+
+        # ezweb
         sub {
             my $serial = $_[0]->get_header('x-up-subno');
             $serial =~ tr/_/-/;
             $serial =~ /\A(\d{14}-\w\w)/xms ? $1 : '';
         },
+
+        # willcom
         sub {''},
+
+        # jig
         sub { $_[0]->get_header('x-subscriber-id') },
+
+        # ibis
         sub {
             my $agent = $_[0]->get_header('user-agent');
             $agent =~ /ibisBrowser;.+;\s*(\w+)/xms;
             $1 || '';
         },
+
+        # pcsb
         sub {
             my $agent = $_[0]->get_header('user-agent');
             $agent =~ /SN(\d+)/xms;
             $1 || '';
-            }
+        },
+
+        # ezweb
+        sub {
+            my $agent = $_[0]->get_header('x-em-uid');
+            $agent =~ /u(\w+)/xms;
+            $1 || '';
+        },
     ]->[$ag]->($iRequest);
     return $id;
 }
 
 sub get_device_mark {
-    my ( $iRequest, $agent, $host ) = @_;
+    my ( $iRequest, $agent, $host, $ua ) = @_;
     $agent ||= $iRequest->{__agent};
     $host  ||= $iRequest->get_remote_host();
-    ( $agent < 0 or $agent > 7 ) and return '0';
-    my $mode = [ '0', 'O', 'O', 'O', 'O', 'Q', 'Q', 'Q' ]->[$agent];
-    $host =~ /(?:p2\.2ch\.net|razil\.jp)\z/xms and $mode = 'P';
+    ( $agent < 0 or $agent > $MAX_DEVICE_MARK_NUM ) and return '0';
+    my $mode = [
+        '0',    # others
+        'O',    # docomo
+        'O',    # softbank
+        'O',    # ezweb
+        'O',    # willcom
+        'Q',    # jig
+        'Q',    # ibis
+        'Q',    # pcsb
+        'O',    # emobile
+    ]->[$agent];
+    $host =~ /p2\.(?:2ch\.net|razil\.jp)\z/xms and $mode = 'P';
+    $ua =~ /iPhone/xms and $mode = 'i';
     return $mode;
 }
 
@@ -245,6 +281,7 @@ sub detect_agent {
     my @vodafone = keys %{ $iConfig->get('vodafone.*') };
     my @au       = keys %{ $iConfig->get('ezweb.*') };
     my @willcom  = keys %{ $iConfig->get('willcom.*') };
+    my @emobile  = keys %{ $iConfig->get('emobile.*') };
     my @jig      = keys %{ $iConfig->get('jig.*') };
     my @ibis     = keys %{ $iConfig->get('ibis.*') };
     my @pcsb     = keys %{ $iConfig->get('pcsb.*') };
@@ -257,6 +294,7 @@ sub detect_agent {
     Net::CIDR::Lite->new(@jig)->find($host)      and return 5;
     Net::CIDR::Lite->new(@ibis)->find($host)     and return 6;
     Net::CIDR::Lite->new(@pcsb)->find($host)     and return 7;
+    Net::CIDR::Lite->new(@emobile)->find($host)  and return 8;
 
     return 0;
 }
